@@ -12,7 +12,7 @@ from small_text.classifiers.classification import EmbeddingMixin
 from small_text.integrations.pytorch.classifiers.base import PytorchClassifier
 from small_text.integrations.pytorch.exceptions import PytorchNotFoundError
 from small_text.integrations.pytorch.models.kimcnn import KimCNN
-from small_text.utils.classification import empty_result, get_splits
+from small_text.utils.classification import get_splits
 from small_text.utils.context import build_pbar_context
 from small_text.utils.data import check_training_data, list_length
 from small_text.utils.annotations import early_stopping_deprecation_warning
@@ -32,6 +32,7 @@ try:
     )
     from small_text.integrations.pytorch.datasets import PytorchTextClassificationDataset
     from small_text.integrations.pytorch.utils.data import dataloader
+    from small_text.integrations.pytorch.utils.misc import enable_dropout
 except ImportError:
     raise PytorchNotFoundError('Could not import pytorch')
 
@@ -501,13 +502,12 @@ class KimCNNClassifier(KimCNNEmbeddingMixin, PytorchClassifier):
 
         return valid_loss / len(validation_set), acc / len(validation_set)
 
-    def predict(self, data_set, return_proba=False):
-        """
-        Predicts the labels for the given dataset.
+    def predict(self, dataset, return_proba=False):
+        """Predicts the labels for the given dataset.
 
         Parameters
         ----------
-        data_set : PytorchTextClassificationDataset
+        dataset : PytorchTextClassificationDataset
             A dataset on whose instances predictions are made.
         return_proba : bool
             If True, additionally returns the confidence distribution over all classes.
@@ -520,28 +520,62 @@ class KimCNNClassifier(KimCNNEmbeddingMixin, PytorchClassifier):
         probas : np.ndarray[np.float32] (optional)
             List of probabilities (or confidence estimates) if `return_proba` is True.
         """
-        return super().predict(data_set, return_proba=return_proba)
+        return super().predict(dataset, return_proba=return_proba)
 
-    def predict_proba(self, data_set):
-        if len(data_set) == 0:
-            return empty_result(self.multi_label, self.num_classes, return_prediction=False,
-                                return_proba=True)
+    def predict_proba(self, dataset, dropout_sampling=1):
+        """Predicts the label distributions.
 
-        self.model.eval()
-        test_iter = dataloader(data_set.data, self.mini_batch_size, self._create_collate_fn(),
-                               train=False)
+        Parameters
+        ----------
+        dataset : PytorchTextClassificationDataset
+            A dataset whose labels will be predicted.
+        dropout_sampling : int
+            If `dropout_sampling > 1` then all dropout modules will be enabled during prediction and
+            multiple rounds of predictions will be sampled for each instance.
 
-        predictions = []
-        logits_transform = torch.sigmoid if self.multi_label else partial(F.softmax, dim=1)
+        Returns
+        -------
+        scores : np.ndarray
+            Distribution of confidence scores over all classes of shape (num_samples, num_classes).
+            If `dropout_sampling > 1` then the shape is (num_samples, dropour_samples, num_classes).
+        """
+        return super().predict_proba(dataset, dropout_sampling=dropout_sampling)
 
-        with torch.no_grad():
-            for text, *_ in test_iter:
+    def _predict_proba(self, dataset_iter, logits_transform):
+        predictions = np.empty((0, self.num_classes), dtype=float)
+        for text, *_ in dataset_iter:
+            text = text.to(self.device)
+            output = self.model.forward(text)
+
+            predictions = np.append(predictions,
+                                    logits_transform(output).to('cpu').numpy(),
+                                    axis=0)
+            del text
+        return predictions
+
+    def _predict_proba_dropout_sampling(self, dataset_iter, logits_transform, dropout_samples=2):
+
+        predictions = np.empty((0, dropout_samples, self.num_classes), dtype=float)
+
+        with enable_dropout(self.model):
+            for text,  *_ in dataset_iter:
+                batch_size, vector_len = text.shape
+                full_size = batch_size * dropout_samples
                 text = text.to(self.device)
+                text = text.repeat(1, dropout_samples).resize(full_size, vector_len)
 
-                predictions += logits_transform(self.model.forward(text)).to('cpu').tolist()
+                output = self.model.forward(text)
+
+                prediction_for_batch = logits_transform(output)
+                prediction_for_batch = prediction_for_batch.unsqueeze(dim=1)\
+                    .resize(batch_size, dropout_samples, self.num_classes)
+
+                predictions = np.append(predictions,
+                                        prediction_for_batch.to('cpu').numpy(),
+                                        axis=0)
                 del text
 
-        return np.array(predictions)
+        return predictions
 
     def __del__(self):
         try:
