@@ -9,7 +9,7 @@ from functools import partial
 
 from small_text.classifiers.classification import EmbeddingMixin
 from small_text.integrations.pytorch.exceptions import PytorchNotFoundError
-from small_text.utils.classification import empty_result, get_splits
+from small_text.utils.classification import get_splits
 from small_text.utils.context import build_pbar_context
 from small_text.utils.data import check_training_data, list_length
 from small_text.utils.datetime import format_timedelta
@@ -26,15 +26,20 @@ try:
     import torch.nn.functional as F  # noqa: N812
 
     from torch.optim import AdamW
-    from transformers import logging as transformers_logging
-    from transformers import AutoConfig, AutoModelForSequenceClassification, AutoTokenizer
 
     from small_text.integrations.pytorch.classifiers.base import (
         _check_optimizer_and_scheduler_config,
         PytorchClassifier
     )
     from small_text.integrations.pytorch.utils.data import dataloader
+    from small_text.integrations.pytorch.utils.misc import enable_dropout
+    from small_text.integrations.transformers.classifiers.base import (
+        ModelLoadingStrategy
+    )
     from small_text.integrations.transformers.datasets import TransformersDataset
+    from small_text.integrations.transformers.utils.classification import (
+        _initialize_transformer_components
+    )
 except ImportError:
     raise PytorchNotFoundError('Could not import pytorch')
 
@@ -62,8 +67,8 @@ def transformers_collate_fn(batch, multi_label=None, num_classes=None, use_sampl
 
 class FineTuningArguments(object):
     """
-    Arguments to enable and configure gradual unfreezing and discriminative learning rates as used in
-    Universal Language Model Fine-tuning (ULMFiT) [HR18]_.
+    Arguments to enable and configure gradual unfreezing and discriminative learning rates as used
+    in Universal Language Model Fine-tuning (ULMFiT) [HR18]_.
     """
 
     def __init__(self, base_lr, layerwise_gradient_decay, gradual_unfreezing=-1, cut_fraction=0.1):
@@ -84,7 +89,26 @@ class FineTuningArguments(object):
 
 class TransformerModelArguments(object):
 
-    def __init__(self, model, tokenizer=None, config=None):
+    def __init__(self,
+                 model,
+                 tokenizer=None,
+                 config=None,
+                 model_loading_strategy: ModelLoadingStrategy = ModelLoadingStrategy.DEFAULT):
+        """
+        Parameters
+        ----------
+        model : str
+            Name of the transformer model. Will be passed into `AutoModel.from_pretrained()`.
+        tokenizer : str, default=None
+            Name of the tokenizer if deviating from the model name. Will be passed
+            into `AutoTokenizer.from_pretrained()`.
+        config : str, default=None
+            Name of the config if deviating from the model name. Will be passed into
+            `AutoConfig.from_pretrained()`.
+        model_loading_strategy: ModelLoadingStrategy, default=ModelLoadingStrategy.DEFAULT
+            Specifies if there should be attempts to download the model or if only local
+            files should be used.
+        """
         self.model = model
         self.tokenizer = tokenizer
         self.config = config
@@ -94,6 +118,8 @@ class TransformerModelArguments(object):
         if self.config is None:
             self.config = model
 
+        self.model_loading_strategy = model_loading_strategy
+
 
 def _get_layer_params(model, base_lr, fine_tuning_arguments):
 
@@ -211,11 +237,24 @@ class TransformerBasedEmbeddingMixin(EmbeddingMixin):
 
 class TransformerBasedClassification(TransformerBasedEmbeddingMixin, PytorchClassifier):
 
-    def __init__(self, transformer_model, num_classes, multi_label=False, num_epochs=10, lr=2e-5,
-                 mini_batch_size=12, validation_set_size=0.1, validations_per_epoch=1,
-                 early_stopping_no_improvement=5, early_stopping_acc=-1, model_selection=True,
-                 fine_tuning_arguments=None, device=None, memory_fix=1, class_weight=None,
-                 verbosity=VERBOSITY_MORE_VERBOSE, cache_dir='.active_learning_lib_cache/'):
+    def __init__(self,
+                 transformer_model: TransformerModelArguments,
+                 num_classes: int,
+                 multi_label: bool = False,
+                 num_epochs: int = 10,
+                 lr: float = 2e-5,
+                 mini_batch_size: int = 12,
+                 validation_set_size: float = 0.1,
+                 validations_per_epoch: int = 1,
+                 early_stopping_no_improvement: int = 5,
+                 early_stopping_acc: float = -1,
+                 model_selection: bool = True,
+                 fine_tuning_arguments=None,
+                 device=None,
+                 memory_fix=1,
+                 class_weight=None,
+                 verbosity=VERBOSITY_MORE_VERBOSE,
+                 cache_dir='.active_learning_lib_cache/'):
         """
         Parameters
         ----------
@@ -396,26 +435,11 @@ class TransformerBasedClassification(TransformerBasedEmbeddingMixin, PytorchClas
 
     def initialize_transformer(self, cache_dir):
 
-        self.config = AutoConfig.from_pretrained(
-            self.transformer_model.config,
-            num_labels=self.num_classes,
-            cache_dir=cache_dir,
+        self.config, self.tokenizer, self.model = _initialize_transformer_components(
+            self.transformer_model,
+            self.num_classes,
+            cache_dir,
         )
-        self.tokenizer = AutoTokenizer.from_pretrained(
-            self.transformer_model.tokenizer,
-            cache_dir=cache_dir,
-        )
-
-        # Suppress "Some weights of the model checkpoint at [model name] were not [...]"-warnings
-        previous_verbosity = transformers_logging.get_verbosity()
-        transformers_logging.set_verbosity_error()
-        self.model = AutoModelForSequenceClassification.from_pretrained(
-            self.transformer_model.model,
-            from_tf=False,
-            config=self.config,
-            cache_dir=cache_dir,
-        )
-        transformers_logging.set_verbosity(previous_verbosity)
 
     def _default_optimizer(self, base_lr):
 
@@ -625,11 +649,12 @@ class TransformerBasedClassification(TransformerBasedEmbeddingMixin, PytorchClas
 
         return valid_loss / len(validation_set), acc / len(validation_set)
 
-    def predict(self, data_set, return_proba=False):
-        """
+    def predict(self, dataset, return_proba=False):
+        """Predicts the labels for the given dataset.
+
         Parameters
         ----------
-        data_set : small_text.integrations.transformers.TransformerDataset
+        dataset : TransformersDataset
             A dataset on whose instances predictions are made.
         return_proba : bool, default=False
             If True, additionally returns the confidence distribution over all classes.
@@ -642,29 +667,63 @@ class TransformerBasedClassification(TransformerBasedEmbeddingMixin, PytorchClas
         probas : np.ndarray[np.float32], optional
             List of probabilities (or confidence estimates) if `return_proba` is True.
         """
-        return super().predict(data_set, return_proba=return_proba)
+        return super().predict(dataset, return_proba=return_proba)
 
-    def predict_proba(self, data_set):
-        if len(data_set) == 0:
-            return empty_result(self.multi_label, self.num_classes, return_prediction=False,
-                                return_proba=True)
+    def predict_proba(self, dataset, dropout_sampling=1):
+        """Predicts the label distributions.
 
-        self.model.eval()
-        test_iter = dataloader(data_set.data, self.mini_batch_size, self._create_collate_fn(),
-                               train=False)
+        Parameters
+        ----------
+        dataset : TransformersDataset
+            A dataset whose labels will be predicted.
+        dropout_sampling : int
+            If `dropout_sampling > 1` then all dropout modules will be enabled during prediction and
+            multiple rounds of predictions will be sampled for each instance.
 
-        predictions = []
-        logits_transform = torch.sigmoid if self.multi_label else partial(F.softmax, dim=1)
+        Returns
+        -------
+        scores : np.ndarray
+            Distribution of confidence scores over all classes of shape (num_samples, num_classes).
+            If `dropout_sampling > 1` then the shape is (num_samples, dropour_samples, num_classes).
+        """
+        return super().predict_proba(dataset, dropout_sampling=dropout_sampling)
 
-        with torch.no_grad():
-            for text, masks, *_ in test_iter:
+    def _predict_proba(self, dataset_iter, logits_transform):
+        predictions = np.empty((0, self.num_classes), dtype=float)
+        for text, masks, *_ in dataset_iter:
+            text, masks = text.to(self.device), masks.to(self.device)
+            outputs = self.model(text, attention_mask=masks)
+
+            predictions = np.append(predictions,
+                                    logits_transform(outputs.logits).to('cpu').numpy(),
+                                    axis=0)
+            del text, masks
+        return predictions
+
+    def _predict_proba_dropout_sampling(self, dataset_iter, logits_transform, dropout_samples=2):
+
+        predictions = np.empty((0, dropout_samples, self.num_classes), dtype=float)
+
+        with enable_dropout(self.model):
+            for text, masks, *_ in dataset_iter:
+                batch_size, vector_len = text.shape
+                full_size = batch_size * dropout_samples
                 text, masks = text.to(self.device), masks.to(self.device)
+                text, masks = text.repeat(1, dropout_samples).resize(full_size, vector_len), \
+                    masks.repeat(1, dropout_samples).resize(full_size, vector_len)
+
                 outputs = self.model(text, attention_mask=masks)
 
-                predictions += logits_transform(outputs.logits).to('cpu').tolist()
+                prediction_for_batch = logits_transform(outputs.logits)
+                prediction_for_batch = prediction_for_batch.unsqueeze(dim=1)\
+                    .resize(batch_size, dropout_samples, self.num_classes)
+
+                predictions = np.append(predictions,
+                                        prediction_for_batch.to('cpu').numpy(),
+                                        axis=0)
                 del text, masks
 
-        return np.array(predictions)
+        return predictions
 
     def __del__(self):
         try:
