@@ -38,6 +38,12 @@ class PytorchClassifierImplementation(PytorchClassifier):
     def predict_proba(self, test_set):
         raise NotImplementedError()
 
+    def _predict_proba(self, dataset_iter, logits_transform):
+        pass
+
+    def _predict_proba_dropout_sampling(self, dataset_iter, logits_transform, dropout_samples=2):
+        pass
+
 
 @pytest.mark.pytorch
 class PytorchClassifierTest(unittest.TestCase):
