@@ -57,7 +57,7 @@ class _ClassifierBaseFunctionalityTest(object):
             self.assertTrue(isinstance(proba, csr_matrix))
         else:
             self.assertTrue(isinstance(proba, np.ndarray))
-            self.assertTrue(np.issubdtype(proba.dtype, np.float))
+            self.assertTrue(np.issubdtype(proba.dtype, float))
 
 
 class SklearnClassifierSingleLabelTest(unittest.TestCase, _ClassifierBaseFunctionalityTest):
@@ -109,9 +109,10 @@ class SklearnClassifierMultiLabelTest(unittest.TestCase, _ClassifierBaseFunction
         train_set = random_sklearn_dataset(10,
                                            num_classes=3 if self._is_multi_label() else 2,
                                            multi_label=self._is_multi_label())
+
         # possibility of error: more than one unique value in y.data
         train_set.y.data = np.random.choice([0, 1], train_set.y.indices.shape[0])
-        train_set.y.data[0:2] = [0, 1]
+        train_set.y.data[0:3] = [0, 1, 2]
         clf = self._get_clf()
 
         expected_str = 'Invalid input: Given labeling must be recognized as multi-label'
